Crate codex_arg0

Crate codex_arg0 

Structs

Arg0DispatchPaths
Arg0PathEntryGuard
Keeps the per-session PATH entry alive and locked for the process lifetime.

Functions

arg0_dispatch
arg0_dispatch_or_else
While we want to deploy the Codex CLI as a single executable for simplicity, we also want to expose some of its functionality as distinct CLIs, so we use the “arg0 trick” to determine which CLI to dispatch. This effectively allows us to simulate deploying multiple executables as a single binary on Mac and Linux (but not Windows).