While we want to deploy the Codex CLI as a single executable for simplicity,
we also want to expose some of its functionality as distinct CLIs, so we use
the “arg0 trick” to determine which CLI to dispatch. This effectively allows
us to simulate deploying multiple executables as a single binary on Mac and
Linux (but not Windows).